AgentState

Enum AgentState 

pub enum AgentState {
    Idle,
    ReachedTarget,
    ReachedAnimationLink,
    UsingAnimationLink,
    Moving,
    AgentNotOnNavMesh,
    TargetNotOnNavMesh,
    NoPath,
    Paused,
}
The state of an agent.

Variants



Idle

The agent is idle, due to not having a target. Note this does not mean that they are motionless. An agent will still avoid nearby agents.



ReachedTarget

The agent has reached their target. The agent may resume moving if the target moves or otherwise changes.

The agent has reached an animation link along its path to the target.

See Agent::reached_animation_link for details about the link.

The agent is currently using an animation link.



Moving

The agent has a path and is moving towards their target.



AgentNotOnNavMesh

The agent is not on a nav mesh.



TargetNotOnNavMesh

The target is not on a nav mesh.



NoPath

The agent has a target but cannot find a path to it.



Paused

The agent is paused.